@@ -3,6 +3,9 @@ Parameter usage / help text formatters
 
 :author: Doug Skrypa
 """
+# pylint: disable=W0613
+
+from __future__ import annotations
 
 from itertools import chain
 from textwrap import indent
@@ -11,7 +14,9 @@ from typing import Type, Tuple
 from ..context import ctx
 from ..exceptions import NoActiveContext
 from ..utils import Bool
-from ..parameters import ParamBase, ParamGroup, ParamOrGroup, ChoiceMap, PassThru, BasePositional, BaseOption
+from ..parameters.base import ParamBase, BasePositional, BaseOption
+from ..parameters.choice_map import ChoiceMap
+from ..parameters import ParamGroup, PassThru, ParamOrGroup
 from .restructured_text import RstTable
 from .utils import HelpEntryFormatter, _should_add_default
 
@@ -24,7 +29,7 @@ class ParamHelpFormatter:
             cls._param_cls_fmt_cls_map[param_cls] = cls
 
     @classmethod
-    def for_param_cls(cls, param_cls: Type['ParamBase']) -> Type['ParamHelpFormatter']:
+    def for_param_cls(cls, param_cls: Type[ParamBase]) -> Type[ParamHelpFormatter]:
         try:
             return cls._param_cls_fmt_cls_map[param_cls]
         except KeyError:
@@ -37,9 +42,8 @@ class ParamHelpFormatter:
         return ParamHelpFormatter
 
     def __new__(cls, param: ParamOrGroup):
-        if cls is ParamHelpFormatter:
-            cls = cls.for_param_cls(param.__class__)
-        return super().__new__(cls)
+        fmt_cls = cls.for_param_cls(param.__class__) if cls is ParamHelpFormatter else cls
+        return super().__new__(fmt_cls)
 
     def __init__(self, param: ParamOrGroup):
         self.param = param
@@ -54,10 +58,10 @@ class ParamHelpFormatter:
         if t is not None:
             try:
                 return t.format_metavar(choice_delim)
-            except Exception:  # noqa
+            except Exception:  # noqa  # pylint: disable=W0703
                 pass
         try:
-            use_type_metavar = ctx.use_type_metavar
+            use_type_metavar = ctx.config.use_type_metavar
         except NoActiveContext:
             use_type_metavar = False
         if use_type_metavar and t is not None:
@@ -169,21 +173,22 @@ class PassThruHelpFormatter(ParamHelpFormatter, param_cls=PassThru):
         return f'-- {usage}' if self.param.required else f'[-- {usage}]'
 
 
-class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa
+class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa  # pylint: disable=W0223
     def format_usage(self, include_meta: Bool = False, full: Bool = False, delim: str = ', ') -> str:
+        # TODO: | between mutually exclusive members, + between dependent?  Different chars?
         choices = ','.join(mem.formatter.format_usage(include_meta, full, delim) for mem in self.param.members)
         return f'{{{choices}}}'
 
     def format_description(self, rst: Bool = False) -> str:
         group = self.param
         if not group.description and not group._name:
-            if ctx.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
+            if ctx.config.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
                 return 'Mutually {} options'.format('exclusive' if group.mutually_exclusive else 'dependent')
             else:
                 return 'Optional arguments'
         else:
             description = group.description or f'{group.name} options'
-            if ctx.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
+            if ctx.config.show_group_type and (group.mutually_exclusive or group.mutually_dependent):
                 description += ' (mutually {})'.format('exclusive' if group.mutually_exclusive else 'dependent')
             return description
 
@@ -196,21 +201,21 @@ class GroupHelpFormatter(ParamHelpFormatter, param_cls=ParamGroup):  # noqa
         else:
             return '\u2502 '  # BOX DRAWINGS LIGHT VERTICAL
 
-    def format_help(self, width: int = 30, clean: Bool = True, prefix: str = '', tw_offset: int = 0) -> str:
+    def format_help(self, width: int = 30, prefix: str = '', tw_offset: int = 0, clean: Bool = True) -> str:
         """
         Prepare the help text for this group.
 
         :param width: The width of the option/action/command column.
-        :param clean: If this group only contains other groups or Action or SubCommand parameters, then omit the
-          description.
         :param prefix: Prefix to add to every line (primarily intended for use with nested groups)
         :param tw_offset: Terminal width offset for text width calculations
+        :param clean: If this group only contains other groups or Action or SubCommand parameters, then omit the
+          description.
         :return: The formatted help text.
         """
         description = self.format_description()
         parts = [f'{description}:']
 
-        if ctx.show_group_tree:
+        if ctx.config.show_group_tree:
             spacer = self._get_spacer()
             tw_offset += 2
         else:
