@@ -7,6 +7,7 @@ Base classes and helpers for Parameters and Groups
 from __future__ import annotations
 
 # import logging
+import re
 from abc import ABC, abstractmethod
 from functools import partial, update_wrapper, reduce
 from itertools import chain
@@ -26,7 +27,7 @@ from ..exceptions import ParamUsageError, NoActiveContext, UnsupportedAction
 from ..inputs import InputType, normalize_input_type, Choices, ChoiceMap as ChoiceMapInput
 from ..inputs.exceptions import InputValidationError, InvalidChoiceError
 from ..nargs import Nargs
-from ..utils import _NotSet, Bool, get_descriptor_value_type, is_numeric
+from ..utils import _NotSet, Bool, get_descriptor_value_type
 
 if TYPE_CHECKING:
     from ..core import CommandType
@@ -88,7 +89,6 @@ class ParamBase(ABC):
     :param hide: If ``True``, this parameter will not be included in usage / help messages.  Defaults to ``False``.
     """
 
-    # fmt: off
     __name: str = None              #: Always the name of the attr that points to this object
     _name: str = None               #: An explicitly provided name, or the name of the attr that points to this object
     group: ParamGroup = None        #: The group this object is a member of, if any
@@ -97,7 +97,6 @@ class ParamBase(ABC):
     help: str = None                #: The description for this param/group that will appear in ``--help`` text
     hide: Bool = False              #: Whether this param/group should be hidden in ``--help`` text
     missing_hint: str = None        #: Hint to provide if this param/group is missing
-    # fmt: on
 
     def __init__(self, name: str = None, required: Bool = False, help: str = None, hide: Bool = False):  # noqa
         self.required = required
@@ -141,9 +140,9 @@ class ParamBase(ABC):
             pass
         raise NoActiveContext('There is no active context')
 
-    def _ctx_or_config(self, command: CommandType) -> Union[CommandConfig, Context]:
+    def _config(self, command: CommandType) -> Union[CommandConfig, Context]:
         try:
-            return self._ctx(command)
+            return self._ctx(command).config
         except NoActiveContext:
             return command.__class__.config(command)
 
@@ -155,7 +154,7 @@ class ParamBase(ABC):
 
         try:
             with self._ctx() as context:
-                formatter_factory = context.param_formatter or ParamHelpFormatter
+                formatter_factory = context.config.param_formatter or ParamHelpFormatter
         except NoActiveContext:
             formatter_factory = ParamHelpFormatter
 
@@ -376,7 +375,7 @@ class Parameter(ParamBase, ABC):
 
     def validate(self, value: Any):
         if isinstance(value, str) and value.startswith('-'):
-            if len(value) > 1 and not is_numeric(value):
+            if len(value) > 1 and not _is_numeric(value):
                 raise BadArgument(self, f'invalid value={value!r}')
         elif value is None:
             if not self.accepts_none:
@@ -542,12 +541,10 @@ class BaseOption(Parameter, ABC):
     :param kwargs: Additional keyword arguments to pass to :class:`Parameter`.
     """
 
-    # fmt: off
     _long_opts: Set[str]                        # --long options
     _short_opts: Set[str]                       # -short options
     short_combinable: Set[str]                  # short options without the leading dash (for combined flags)
     name_mode: Optional[OptionNameMode] = None  # OptionNameMode override
-    # fmt: on
 
     def __init__(self, *option_strs: str, action: str, name_mode: Union[OptionNameMode, str] = None, **kwargs):
         bad_opts = ', '.join(opt for opt in option_strs if not 0 < opt.count('-', 0, 3) < 3)
@@ -573,7 +570,7 @@ class BaseOption(Parameter, ABC):
     def __set_name__(self, command: CommandType, name: str):
         super().__set_name__(command, name)
         if not self._long_opts:
-            mode = self.name_mode if self.name_mode is not None else self._ctx_or_config(command).option_name_mode
+            mode = self.name_mode if self.name_mode is not None else self._config(command).option_name_mode
             if mode & OptionNameMode.DASH:
                 self._long_opts.add('--{}'.format(name.replace('_', '-')))
             if mode & OptionNameMode.UNDERSCORE:
@@ -592,5 +589,13 @@ class BaseOption(Parameter, ABC):
         return sorted(self._short_opts, key=lambda opt: (-len(opt), opt))
 
 
+def _is_numeric(text: str) -> Bool:
+    try:
+        num_match = _is_numeric._num_match
+    except AttributeError:
+        _is_numeric._num_match = num_match = re.compile(r'^-\d+$|^-\d*\.\d+?$').match
+    return num_match(text)
+
+
 # Down here due to circular dependency
 from .groups import ParamGroup  # pylint: disable=C0413
